@@ -23,16 +23,14 @@ authres extension module for RFC 6008 DKIM signature identification (header.b).
 
 __author__  = 'Scott Kitterman, Julian Mehnle'
 __email__   = 'scott@kitterman.com'
-__version__ = '0.500'
+__version__ = '0.501'
 
 import authres.core
 from authres.core import make_result_class_properties
 
-class DKIMAuthenticationResult(authres.core.AuthenticationResult):
+class DKIMAuthenticationResult(authres.core.DKIMAuthenticationResult):
     "DKIM result clause of an ``Authentication-Results`` header"
 
-    METHOD = 'dkim'
-
     def __init__(self, version = None,
         result               = None,  result_comment               = None,
         reason               = None,  reason_comment               = None,
@@ -41,17 +39,12 @@ class DKIMAuthenticationResult(authres.core.AuthenticationResult):
         header_i             = None,  header_i_comment             = None,
         header_b             = None,  header_b_comment             = None
     ):
-        authres.core.AuthenticationResult.__init__(self, self.METHOD, version,
-            result, result_comment, reason, reason_comment, properties)
-        if header_d:                     self.header_d                     = header_d
-        if header_d_comment:             self.header_d_comment             = header_d_comment
-        if header_i:                     self.header_i                     = header_i
-        if header_i_comment:             self.header_i_comment             = header_i_comment
+        authres.core.DKIMAuthenticationResult.__init__(self, version,
+            result, result_comment, reason, reason_comment, properties,
+            header_d, header_d_comment, header_i, header_i_comment)
         if header_b:                     self.header_b                     = header_b
         if header_b_comment:             self.header_b_comment             = header_b_comment
 
-    header_d,             header_d_comment             = make_result_class_properties('header', 'd')
-    header_i,             header_i_comment             = make_result_class_properties('header', 'i')
     header_b,             header_b_comment             = make_result_class_properties('header', 'b')
 
     def match_signature(self, signature_d, signature_b = None, strict = False):
